@@ -16,28 +16,28 @@
 #define   __CONF_HOST           "@host@"
 #define   __CONF_ARCH           "x86_64"
 
-#define   __CONF_CC             "cc"
+#define   __CONF_CC             "icc"
 #define   __CONF_CFLAGS         "-O3"
-#define   __CONF_DFLAGS         " -D__FFTW3 -D__MPI"
+#define   __CONF_DFLAGS         " -D__DFTI -D__MPI -D__SCALAPACK"
 #define   __CONF_CPP            "cpp"
 #define   __CONF_CPPFLAGS       "-P -traditional -Uvector"
 
-#define   __CONF_F90            "gfortran"
+#define   __CONF_F90            "ifort"
 #define   __CONF_MPIF90         "mpif90"
-#define   __CONF_F90FLAGS       "$(FFLAGS) -cpp"
+#define   __CONF_F90FLAGS       "$(FFLAGS) -nomodule"
 #define   __CONF_F77            "@f77@"
-#define   __CONF_FFLAGS         "-O3 -g -fallow-argument-mismatch"
-#define   __CONF_FFLAGS_NOOPT   "-O0 -g"
-#define   __CONF_PRE_FDFLAGS    ""
+#define   __CONF_FFLAGS         "-O2 -assume byterecl -g -traceback"
+#define   __CONF_FFLAGS_NOOPT   "-O0 -assume byterecl -g -traceback"
+#define   __CONF_PRE_FDFLAGS    "-fpp -allow nofpp_comments "
 #define   __CONF_FDFLAGS        "$(DFLAGS) $(MANUAL_DFLAGS)"
 
 #define   __CONF_LD             "mpif90"
-#define   __CONF_LDFLAGS        "-g"
+#define   __CONF_LDFLAGS        " "
 #define   __CONF_IMOD           "-I"
 
-#define   __CONF_BLAS_LIBS      " -lopenblas "
-#define   __CONF_LAPACK_LIBS    "-L/usr/local/lib  -lopenblas "
-#define   __CONF_FFT_LIBS       " -lfftw3 "
+#define   __CONF_BLAS_LIBS      "  -lmkl_intel_lp64  -lmkl_sequential -lmkl_core"
+#define   __CONF_LAPACK_LIBS    ""
+#define   __CONF_FFT_LIBS       ""
 #define   __CONF_MASS_LIBS      ""
 
 #define   __CONF_AR             "ar"
